@@ -1,7 +1,7 @@
 from .callbacks_base import TensorboardCallbackBase
 
 
-class MTTensorboardCallback(TensorboardCallbackBase):
+class TFTTensorboardCallback(TensorboardCallbackBase):
     def __init__(self, tensorboard_logger):
         super().__init__(tensorboard_logger)
 
