@@ -11,8 +11,8 @@ from torch.utils.data import Dataset
 import mlflow
 import pytorch_lightning as pl
 from pytorch_lightning import LightningModule
-from rbi_ml.lightning.callbacks_base import AttnVisCallbackBase, TensorboardCallbackBase
-from rbi_ml.models.txt import TxT
+from .callbacks_base import AttnVisCallbackBase, TensorboardCallbackBase
+from ..models.txt import TxT
 
 
 class TxTTensorboardCallback(TensorboardCallbackBase):
